@@ -25,7 +25,7 @@
 #include "maindialog.h"
 #include "maindialog.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QFile>
 #include <QFileInfo>
@@ -34,7 +34,7 @@
 #include <QStringList>
 #include <QTime>
 
-// KDE includes.
+// KDE includes
 
 #include <kdebug.h>
 #include <kicon.h>
@@ -43,7 +43,7 @@
 #include <kurl.h>
 #include <kstandarddirs.h>
 
-// Local includes.
+// Local includes
 
 #include "imagedialog.h"
 #include "listimageitems.h"
@@ -245,10 +245,7 @@ void MainDialog::ShowNumberImages( int Number )
     // Notify total time is changed
     emit totalTimeChanged(m_totalTime);
 
-    if ( Number == 1 )
-        m_label6->setText(i18n("%1 image [%2]", Number, TotalDuration.toString()));
-    else
-        m_label6->setText(i18n("%1 images [%2]", Number, TotalDuration.toString()));
+    m_label6->setText(i18np("%1 image [%2]", "%1 images [%2]", Number, TotalDuration.toString()));
 }
 
 void MainDialog::loadEffectNames()
@@ -320,7 +317,7 @@ bool MainDialog::updateUrlList()
         if (!QFile::exists(pitem->path()))
         {
             KMessageBox::error(this,
-                               i18n("Cannot access to file %1, please check the path is right.", pitem->path()));
+                               i18n("Cannot access file %1. Please check the path is correct.", pitem->path()));
             return false;
         }
 
@@ -357,7 +354,7 @@ void MainDialog::slotImagesFilesSelected( int row )
 
     int index = m_ImagesFilesListBox->row ( item );
 
-    m_label7->setText(i18n("Image no. %1", QString::number(index + 1)));
+    m_label7->setText(i18nc("Image number %1", "Image #%1", QString::number(index + 1)));
 }
 
 void MainDialog::addItems(const KUrl::List& fileList)
@@ -437,7 +434,7 @@ void MainDialog::slotImagesFilesButtonUp( void )
 
     if  (Cpt > 1)
     {
-        KMessageBox::error(this, i18n("You can only move up one image file at once."));
+        KMessageBox::error(this, i18n("You can only move image files up one at a time."));
         return;
     }
 
@@ -466,7 +463,7 @@ void MainDialog::slotImagesFilesButtonDown( void )
 
     if (Cpt > 1)
     {
-        KMessageBox::error(this, i18n("You can only move down one image file at once."));
+        KMessageBox::error(this, i18n("You can only move image files down one at a time."));
         return;
     }
 
@@ -532,7 +529,7 @@ void MainDialog::slotUseMillisecondsToggled( void )
     }
     else
     {
-        m_delayLabel->setText(i18n("Delay between images  (s):"));
+        m_delayLabel->setText(i18n("Delay between images (s):"));
 
         m_delaySpinBox->setRange(m_sharedData->delayMsMinValue / 100, m_sharedData->delayMsMaxValue / 10);
         m_delaySpinBox->setSingleStep(m_sharedData->delayMsLineStep / 100);
