@@ -6,7 +6,7 @@
  * Date        : 2004-10-01
  * Description : a kipi plugin to batch process images
  *
- * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,38 +23,37 @@
 #ifndef BATCHPROCESSIMAGE_H
 #define BATCHPROCESSIMAGE_H
 
-// Include files for Qt
+// Qt includes
 
-#include <qobject.h>
-//Added by qt3to4:
-#include <QDropEvent>
 #include <QDragEnterEvent>
+#include <QDropEvent>
+#include <QObject>
+#include <QTreeWidget>
 
-// Include files for KDE
-
-#include <k3listview.h>
+// KDE includes
 
 namespace KIPIBatchProcessImagesPlugin
 {
 
-class BatchProcessImagesList : public K3ListView
+class BatchProcessImagesList : public QTreeWidget
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
-    BatchProcessImagesList(QWidget *parent=0, const char *name=0);
+
+    BatchProcessImagesList(QWidget *parent=0);
 
 signals:
+
     void addedDropItems(QStringList filesPath);
 
 protected:
+
     void dragEnterEvent(QDragEnterEvent *e);
+    void dragMoveEvent(QDragMoveEvent *e);
     void dropEvent(QDropEvent* e);
-    bool acceptDrag(QDropEvent* e) const;
-    void contentsDropEvent(QDropEvent* e);
-    void droppedImagesItems(QDropEvent *e);
 };
 
-}  // NameSpace KIPIBatchProcessImagesPlugin
+}  // namespace KIPIBatchProcessImagesPlugin
 
-#endif
+#endif // BATCHPROCESSIMAGE_H
