@@ -23,16 +23,16 @@
 #ifndef COLOROPTIONSDIALOG_H
 #define COLOROPTIONSDIALOG_H
 
-// Include files for Qt
+// Qt includes
 
-#include <qstring.h>
+#include <QString>
 
-// Include files for KDE
+// KDE includes
 
 #include <kdialog.h>
 
-class QComboBox;
 
+class KComboBox;
 class KIntNumInput;
 
 namespace KIPIBatchProcessImagesPlugin
@@ -47,7 +47,7 @@ public:
    ColorOptionsDialog(QWidget *parent=0, int ColorType = 0);
    ~ColorOptionsDialog();
 
-   QComboBox       *m_depthValue;
+   KComboBox       *m_depthValue;
 
    KIntNumInput    *m_fuzzDistance;
 
@@ -55,6 +55,6 @@ public:
    KIntNumInput    *m_segmentSmooth;
 };
 
-}  // NameSpace KIPIBatchProcessImagesPlugin
+}  // namespace KIPIBatchProcessImagesPlugin
 
 #endif  // COLOROPTIONSDIALOG_H
