@@ -23,41 +23,42 @@
 #include "convertimagesdialog.h"
 #include "convertimagesdialog.moc"
 
-// Include files for Qt
+// Qt includes
 
-#include <q3groupbox.h>
-#include <qlabel.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qfileinfo.h>
-#include <qdir.h>
+#include <QGroupBox>
+#include <QCheckBox>
+#include <QDir>
+#include <QFileInfo>
+#include <QLabel>
+#include <QPushButton>
 
-// Include files for KDE
+// KDE includes
 
-#include <klocale.h>
+#include <kapplication.h>
+#include <kcombobox.h>
 #include <kconfig.h>
+#include <kdebug.h>
+#include <khelpmenu.h>
+#include <kiconloader.h>
+#include <klocale.h>
+#include <kmenu.h>
 #include <kmessagebox.h>
 #include <knuminput.h>
 #include <kprocess.h>
-#include <kapplication.h>
-#include <khelpmenu.h>
-#include <kiconloader.h>
-#include <kmenu.h>
-#include <kurlrequester.h>
 #include <ktoolinvocation.h>
+#include <kurlrequester.h>
 
-// LibKExiv2 includes. 
+// LibKExiv2 includes
 
 #include <libkexiv2/kexiv2.h>
 
 // Local includes
 
-#include "dialogutils.h"
-#include "pluginsversion.h"
-#include "kpaboutdata.h"
 #include "convertoptionsdialog.h"
+#include "dialogutils.h"
+#include "kpaboutdata.h"
 #include "outputdialog.h"
+#include "pluginsversion.h"
 
 namespace KIPIBatchProcessImagesPlugin
 {
@@ -96,39 +97,39 @@ ConvertImagesDialog::ConvertImagesDialog( KUrl::List urlList, KIPI::Interface* i
     m_Type->insertItem("TGA");
     m_Type->insertItem("EPS");
     m_Type->setCurrentText("JPEG");
-    whatsThis = i18n("<p>Select here the target image file format.<p>");
-    whatsThis = whatsThis + i18n("<b>JPEG</b>: The Joint Photographic Experts Group's file format is a "
-                                 "good Web file format but it uses lossy data compression.<p>"
-                                 "<b>PNG</b>: the Portable Network Graphics format is an extensible file "
+    whatsThis = i18n("<p>Select here the target image file format.</p>");
+    whatsThis = whatsThis + i18n("<p><b>JPEG</b>: The Joint Photographic Experts Group's file format is a "
+                                 "good Web file format but it uses lossy data compression.</p>"
+                                 "<p><b>PNG</b>: the Portable Network Graphics format is an extensible file "
                                  "format for the lossless, portable, well-compressed storage of raster images. "
                                  "PNG provides a patent-free replacement for GIF and can also replace many common "
                                  "uses of TIFF. PNG is designed to work well in online viewing applications, such "
                                  "as the World Wide Web, so it is fully streamable with a progressive display "
                                  "option. Also, PNG can store gamma and chromaticity data for improved color "
-                                 "matching on heterogeneous platforms.");
+                                 "matching on heterogeneous platforms.</p>");
     whatsThis = whatsThis + i18n("<p><b>TIFF</b>: the Tag Image File Format is a rather old standard that is "
                                  "still very popular today. It is a highly flexible and platform-independent "
                                  "format which is supported by numerous image processing applications and "
-                                 "virtually all prepress software on the market.");
+                                 "virtually all prepress software on the market.</p>");
     whatsThis = whatsThis + i18n("<p><b>PPM</b>: the Portable Pixel Map file format is used as an "
                                  "intermediate format for storing color bitmap information. PPM files "
                                  "may be either binary or ASCII and store pixel values up to 24 bits in size. "
                                  "This format generate the largest-sized text files to encode images without "
-                                 "losing quality");
+                                 "losing quality.</p>");
     whatsThis = whatsThis + i18n("<p><b>BMP</b>: the BitMaP file format is a popular image format from Win32 "
                                  "environment. It efficiently stores mapped or unmapped RGB graphics data with "
                                  "pixels 1-, 4-, 8-, or 24-bits in size. Data may be stored raw or compressed "
                                  "using a 4-bit or 8-bit RLE data compression algorithm. BMP is an excellent "
                                  "choice for a simple bitmap format which supports a wide range of RGB image "
-                                 "data.");
+                                 "data.</p>");
     whatsThis = whatsThis + i18n("<p><b>TGA</b>: the TarGA image file format is one of the most widely used "
                                  "bitmap file formats for storage of 24 and 32 bits truecolor images.  "
                                  "TGA supports colormaps, alpha channel, gamma value, postage stamp image, "
-                                 "textual information, and developer-definable data.");
+                                 "textual information, and developer-definable data.</p>");
     whatsThis = whatsThis + i18n("<p><b>EPS</b>: the  Adobe Encapsulated PostScript image file format "
                                  "is a PostScript language program describing the appearance of a single page. "
                                  "Usually, the purpose of the EPS file is to be embedded inside another PostScript "
-                                 "language page description.");
+                                 "language page description.</p>");
 
     m_Type->setWhatsThis(whatsThis );
 
@@ -204,7 +205,7 @@ void ConvertImagesDialog::readSettings(void)
     KConfig config("kipirc");
     KConfigGroup group = config.group("ConvertImages Settings");
 
-    m_Type->setCurrentItem(group.readEntry("ImagesFormat", 0));  // JPEG per default
+    m_Type->setCurrentIndex(group.readEntry("ImagesFormat", 0));  // JPEG per default
     if ( group.readEntry("CompressLossLess", "false") == "true")
        m_compressLossLess = true;
     else
@@ -214,7 +215,7 @@ void ConvertImagesDialog::readSettings(void)
     m_TIFFCompressionAlgo = group.readEntry("TIFFCompressionAlgo", i18n("None"));
     m_TGACompressionAlgo = group.readEntry("TGACompressionAlgo", i18n("None"));
 
-    m_overWriteMode->setCurrentItem(group.readEntry("OverWriteMode", 2));  // 'Rename' per default...
+    m_overWriteMode->setCurrentIndex(group.readEntry("OverWriteMode", 2));  // 'Rename' per default...
 
     if (group.readEntry("RemoveOriginal", "false") == "true")
         m_removeOriginal->setChecked( true );
@@ -311,12 +312,12 @@ void ConvertImagesDialog::initProcess(KProcess* proc, BatchProcessImagesItem *it
 
 void ConvertImagesDialog::processDone()
 {
-    if (m_Type->currentItem() == 0) 
+    if (m_Type->currentItem() == 0)
     {
         // JPEG file, we remove IPTC preview.
 
         BatchProcessImagesItem *item = dynamic_cast<BatchProcessImagesItem*>(
-                                       m_listFile2Process_iterator->current() );
+                                       **m_listFile2Process_iterator );
         if (item)
         {
             QString src = item->pathSrc();
@@ -325,19 +326,19 @@ void ConvertImagesDialog::processDone()
 
             kDebug() << src << endl;
             kDebug() << tgt << fi.size()<< endl;
-            
+
             KExiv2Iface::KExiv2 metaSrc(src);
-    
+
             // Update Iptc preview.
             // NOTE: see B.K.O #130525. a JPEG segment is limited to 64K. If the IPTC byte array is
             // bigger than 64K duing of image preview tag size, the target JPEG image will be
             // broken. Note that IPTC image preview tag is limited to 256K!!!
             // There is no limitation with TIFF and PNG about IPTC byte array size.
-        
+
             metaSrc.removeIptcTag("Iptc.Application2.Preview");
             metaSrc.removeIptcTag("Iptc.Application2.PreviewFormat");
             metaSrc.removeIptcTag("Iptc.Application2.PreviewVersion");
-            
+
             KExiv2Iface::KExiv2 metaTgt(tgt);
             metaTgt.setIptc(metaSrc.getIptc());
             metaTgt.applyChanges();
@@ -367,4 +368,4 @@ QString ConvertImagesDialog::ImageFileExt(QString Ext)
        return (Ext.toLower());
 }
 
-}  // NameSpace KIPIBatchProcessImagesPlugin
+}  // namespace KIPIBatchProcessImagesPlugin
