@@ -23,34 +23,34 @@
 #include "recompressimagesdialog.h"
 #include "recompressimagesdialog.moc"
 
-// Include files for Qt
+// Qt includes
 
-#include <q3groupbox.h>
-#include <qlabel.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
+#include <QGroupBox>
+#include <QCheckBox>
+#include <QLabel>
+#include <QPushButton>
 
-// Include files for KDE
+// KDE includes
 
-#include <klocale.h>
+#include <kapplication.h>
+#include <kcombobox.h>
 #include <kconfig.h>
+#include <khelpmenu.h>
+#include <kiconloader.h>
+#include <klocale.h>
+#include <kmenu.h>
 #include <kmessagebox.h>
 #include <knuminput.h>
 #include <kprocess.h>
-#include <kapplication.h>
-#include <khelpmenu.h>
-#include <kiconloader.h>
-#include <kmenu.h>
 #include <ktoolinvocation.h>
 
 // Local includes
 
 #include "dialogutils.h"
 #include "kpaboutdata.h"
+#include "outputdialog.h"
 #include "pluginsversion.h"
 #include "recompressoptionsdialog.h"
-#include "outputdialog.h"
 
 namespace KIPIBatchProcessImagesPlugin
 {
@@ -144,7 +144,7 @@ void RecompressImagesDialog::readSettings(void)
     m_TIFFCompressionAlgo = group.readEntry("TIFFCompressionAlgo", i18n("None"));
     m_TGACompressionAlgo = group.readEntry("TGACompressionAlgo", i18n("None"));
 
-    m_overWriteMode->setCurrentItem(group.readEntry("OverWriteMode", 2));  // 'Rename' per default...
+    m_overWriteMode->setCurrentIndex(group.readEntry("OverWriteMode", 2));  // 'Rename' per default...
 
     if (group.readEntry("RemoveOriginal", "false") == "true")
         m_removeOriginal->setChecked( true );
@@ -249,11 +249,11 @@ bool RecompressImagesDialog::prepareStartProcess(BatchProcessImagesItem *item,
 {
     QString imageExt = item->nameSrc().section('.', -1 );
 
-    if (imageExt != "JPEG" && imageExt != "jpeg" && 
+    if (imageExt != "JPEG" && imageExt != "jpeg" &&
         imageExt != "JPG"  && imageExt != "jpg"  &&
         imageExt != "JPE"  && imageExt != "jpe"  &&
         imageExt != "PNG"  && imageExt != "png"  &&
-        imageExt != "TIFF" && imageExt != "tiff" && 
+        imageExt != "TIFF" && imageExt != "tiff" &&
         imageExt != "TIF"  && imageExt != "tif"  &&
         imageExt != "TGA"  && imageExt != "tga")
         {
@@ -265,4 +265,4 @@ bool RecompressImagesDialog::prepareStartProcess(BatchProcessImagesItem *item,
     return true;
 }
 
-}  // NameSpace KIPIBatchProcessImagesPlugin
+}  // namespace KIPIBatchProcessImagesPlugin
