@@ -1,5 +1,3 @@
-//Added by qt3to4:
-#include <QPixmap>
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
@@ -8,7 +6,7 @@
  * Date        : 2003-10-01
  * Description : a kipi plugin to batch process images
  *
- * Copyright (C) 2003-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2003-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2005 by Owen Hirst <n8rider@sbcglobal.net>
  *
  * This program is free software; you can redistribute it
@@ -23,7 +21,10 @@
  *
  * ============================================================ */
 
-// C Ansi includes.
+#include "renameimageswidget.h"
+#include "renameimageswidget.moc"
+
+// C ANSI includes
 
 extern "C"
 {
@@ -32,54 +33,50 @@ extern "C"
 #include <unistd.h>
 }
 
-// C++ includes.
+// C++ includes
 
 #include <cstdio>
 #include <ctime>
 
-// Qt includes.
+// Qt includes
 
-#include <q3listview.h>
-#include <qlineedit.h>
-#include <qcheckbox.h>
-#include <qspinbox.h>
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qcombobox.h>
-#include <qtimer.h>
-#include <q3progressdialog.h>
-#include <q3groupbox.h>
-#include <q3popupmenu.h>
-#include <qregexp.h>
-#include <qdir.h>
-#include <qtooltip.h>
+#include <QGroupBox>
+#include <Q3PopupMenu>
+#include <Q3ProgressDialog>
+#include <QCheckBox>
+#include <QDir>
+#include <QFile>
+#include <QFileInfo>
+#include <QLabel>
+#include <QLineEdit>
+#include <QPixmap>
+#include <QPushButton>
+#include <QRegExp>
+#include <QSpinBox>
+#include <QTimer>
+#include <QToolTip>
 
-// KDE includes.
+// KDE includes
 
-#include <klocale.h>
 #include <kconfig.h>
-#include <kio/previewjob.h>
-#include <kio/renamedialog.h>
 #include <kdebug.h>
 #include <kdeversion.h>
+#include <kio/previewjob.h>
+#include <kio/renamedialog.h>
+#include <klocale.h>
 
-// Libkipi includes.
+// LibKIPI includes
 
 #include <libkipi/interface.h>
 #include <libkipi/imageinfo.h>
 
-// Libkipiplugins includes.
+// LibKIPI includes
 
 #include "imagedialog.h"
 
-// Local includes.
+// Local includes
 
 #include "batchprocessimagesitem.h"
-#include "renameimageswidget.h"
-#include "renameimageswidget.moc"
-#include <imagedialog.h>
 
 namespace KIPIBatchProcessImagesPlugin
 {
@@ -92,13 +89,6 @@ RenameImagesWidget::RenameImagesWidget(QWidget *parent,
       m_urlList(urlList)
 {
     setupUi(this);
-    m_listView->setSorting(-1);
-#if KDE_IS_VERSION(3,4,0)
-    // next can be done directly into designer but it seems not to compile
-    // under kde < 3.4.0
-    m_listView->setShadeSortColumn( FALSE );
-#endif
-
     readSettings();
 
     Q3PopupMenu* sortMenu = new Q3PopupMenu(this);
@@ -123,10 +113,10 @@ RenameImagesWidget::RenameImagesWidget(QWidget *parent,
             "[B:4..-2] - base name (big one - all before last ',', from 4-th to one before last characters)\n"
             "[b-:-3..] - base name (small one - all before first '.', last 3 characters)");
 
-    connect(m_listView, SIGNAL(doubleClicked(Q3ListViewItem*)),
-            SLOT(slotListViewDoubleClicked(Q3ListViewItem*)));
-    connect(m_listView, SIGNAL(selectionChanged(Q3ListViewItem*)),
-            SLOT(slotImageSelected(Q3ListViewItem*)));
+    connect(m_listView, SIGNAL(itemDoubleClicked(QTreeWidgetItem*, int)),
+            SLOT(slotListViewDoubleClicked(QTreeWidgetItem*)));
+    connect(m_listView, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)),
+            SLOT(slotImageSelected(QTreeWidgetItem*)));
 
     connect(m_prefixEdit, SIGNAL(textChanged(const QString&)),
             SLOT(slotOptionsChanged()));
@@ -150,16 +140,16 @@ RenameImagesWidget::RenameImagesWidget(QWidget *parent,
 
 	connect(sortMenu, SIGNAL(activated(int)),
 			SLOT(sortList(int)) );
-	
+
 	connect(m_reverseList, SIGNAL(clicked()),
 			SLOT(reverseList()) );
 
     connect(m_moveUp, SIGNAL(clicked()),
             SLOT(moveCurrentItemUp()) );
-    
+
     connect(m_moveDown, SIGNAL(clicked()),
             SLOT(moveCurrentItemDown()) );
-    
+
     m_timer = new QTimer(this);
     m_progress = new Q3ProgressDialog(this, 0, true);
     connect(m_timer, SIGNAL(timeout()),
@@ -167,6 +157,7 @@ RenameImagesWidget::RenameImagesWidget(QWidget *parent,
     connect(m_progress, SIGNAL(canceled()),
             SLOT(slotAbort()));
 
+    kDebug() << m_urlList;
     for (KUrl::List::iterator it = m_urlList.begin();
          it != m_urlList.end(); ++it)
     {
@@ -184,7 +175,7 @@ RenameImagesWidget::~RenameImagesWidget()
 {
     delete m_timer;
     delete m_progress;
-    
+
     saveSettings();
 }
 
@@ -232,12 +223,12 @@ void RenameImagesWidget::slotOptionsChanged()
     updateListing();
 }
 
-void RenameImagesWidget::slotListViewDoubleClicked(Q3ListViewItem*)
+void RenameImagesWidget::slotListViewDoubleClicked(QTreeWidgetItem*)
 {
-    // TODO: Implement    
+    // TODO: Implement
 }
 
-void RenameImagesWidget::slotImageSelected(Q3ListViewItem* item)
+void RenameImagesWidget::slotImageSelected(QTreeWidgetItem* item)
 {
     if (!item)
     {
@@ -247,7 +238,7 @@ void RenameImagesWidget::slotImageSelected(Q3ListViewItem* item)
 
     m_removeButton->setEnabled(true);
     m_pixLabel->clear();
-    
+
     BatchProcessImagesItem* it = static_cast<BatchProcessImagesItem*>(item);
     KIO::PreviewJob* thumbJob = KIO::filePreview(KUrl(it->pathSrc()),
                                                  m_pixLabel->height() );
@@ -261,10 +252,10 @@ void RenameImagesWidget::sortList(int intSortOrder)
 {
     SortOrder sortOrder = static_cast<SortOrder>(intSortOrder);
 
-    for (Q3ListViewItem* it = m_listView->firstChild(); it;
-         it = it->nextSibling())
+    QTreeWidgetItemIterator it(m_listView->topLevelItem(0));
+    for (; *it; ++it)
     {
-        BatchProcessImagesItem* item = static_cast<BatchProcessImagesItem*>(it);
+        BatchProcessImagesItem* item = static_cast<BatchProcessImagesItem*>(*it);
 
         switch (sortOrder)
         {
@@ -288,12 +279,9 @@ void RenameImagesWidget::sortList(int intSortOrder)
         }
         }
     };
-    
-    // Update list order. We need to set the sorting column temporarily
-    // otherwise sort() won't do anything
-    m_listView->setSorting(1);
-    m_listView->sort();
-    m_listView->setSorting(-1);
+
+    // FIXME: test
+    m_listView->sortItems(-1, Qt::AscendingOrder);
 
     updateListing();
 }
@@ -301,44 +289,48 @@ void RenameImagesWidget::sortList(int intSortOrder)
 
 void RenameImagesWidget::reverseList()
 {
-    if (m_listView->childCount() < 2) return;
+    if (m_listView->topLevelItemCount() < 2) return;
 
-    Q3ListViewItem* lastItem = m_listView->lastItem();
-
-    while (m_listView->firstChild() != lastItem) {
-        m_listView->firstChild()->moveItem(lastItem);
+    QList<QTreeWidgetItem*> lst;
+    while (m_listView->topLevelItemCount() > 0) {
+        lst.prepend(m_listView->takeTopLevelItem(0));
     }
+    m_listView->addTopLevelItems(lst);
 
     updateListing();
 }
 
 
 void RenameImagesWidget::moveCurrentItemUp() {
-    Q3ListViewItem* currentItem = m_listView->currentItem();
+    QTreeWidgetItem* currentItem = m_listView->currentItem();
     if (!currentItem) return;
 
-    for (Q3ListViewItem* previousItem = m_listView->firstChild(); previousItem;
-         previousItem = previousItem->nextSibling()) 
-    {
-        if (previousItem->nextSibling() == currentItem) {
-            previousItem->moveItem(currentItem);
-            break;
-        }
+    int index = m_listView->indexOfTopLevelItem(currentItem);
+    if (index == 0) {
+        return;
     }
 
+    m_listView->takeTopLevelItem(index);
+    m_listView->insertTopLevelItem(index - 1, currentItem);
+    m_listView->setCurrentItem(currentItem);
+
     updateListing();
 }
 
 
 void RenameImagesWidget::moveCurrentItemDown() {
-    Q3ListViewItem* currentItem = m_listView->currentItem();
+    QTreeWidgetItem* currentItem = m_listView->currentItem();
     if (!currentItem) return;
-    
-    Q3ListViewItem* nextItem = currentItem->nextSibling();
-    if (nextItem) {
-        currentItem->moveItem(nextItem);
+
+    int index = m_listView->indexOfTopLevelItem(currentItem);
+    if (index == m_listView->topLevelItemCount() - 1) {
+        return;
     }
 
+    m_listView->takeTopLevelItem(index);
+    m_listView->insertTopLevelItem(index + 1, currentItem);
+    m_listView->setCurrentItem(currentItem);
+
     updateListing();
 }
 
@@ -346,10 +338,10 @@ void RenameImagesWidget::moveCurrentItemDown() {
 void RenameImagesWidget::updateListing()
 {
     int pos = 0;
-    for (Q3ListViewItem* it = m_listView->firstChild(); it;
-         it = it->nextSibling())
+    QTreeWidgetItemIterator it(m_listView);
+    for (; *it; ++it)
     {
-        BatchProcessImagesItem* item = static_cast<BatchProcessImagesItem*>(it);
+        BatchProcessImagesItem* item = static_cast<BatchProcessImagesItem*>(*it);
         item->changeNameDest(oldToNewName(item, pos));
         item->changeResult(QString());
         item->changeError(QString());
@@ -367,12 +359,12 @@ QString RenameImagesWidget::oldToNewName(BatchProcessImagesItem* item,
     QFileInfo fi(item->pathSrc());
 
     KIPI::ImageInfo info = m_interface->info(url);
-    
-    bool useExtraSymbols = m_addFileDateCheck->isChecked() && 
+
+    bool useExtraSymbols = m_addFileDateCheck->isChecked() &&
         m_useExtraSymbolsCheck->isChecked();
 
     QString newName = m_prefixEdit->text();
-    
+
     if (m_addFileNameCheck->isChecked())
     {
         newName += fi.baseName();
@@ -413,17 +405,17 @@ QString RenameImagesWidget::oldToNewName(BatchProcessImagesItem* item,
                 else
                 {
                     if ((i = rxN.search(format)) == -1)
-                    { 
-                        break; 
+                    {
+                        break;
                     }
                     j = rxN.matchedLength();
                     QString from = rxN.cap(1);
-                    from = (from == "e") ? fi.extension(/*complete=*/FALSE) :
-                           (from == "E") ? fi.extension(/*complete=*/TRUE) :
-                           (from == "b") ? fi.baseName(/*complete=*/FALSE) :
-                           (from == "B") ? fi.baseName(/*complete=*/TRUE) :
+                    from = (from == "e") ? fi.extension(/*complete=*/false) :
+                           (from == "E") ? fi.extension(/*complete=*/true) :
+                           (from == "b") ? fi.baseName(/*complete=*/false) :
+                           (from == "B") ? fi.baseName(/*complete=*/true) :
                            (from == "n") ? fi.fileName() :
-                           (from == "a") ? fi.dir(/*absPath=*/TRUE).dirName() :
+                           (from == "a") ? fi.dir(/*absPath=*/true).dirName() :
                            (from == "p") ? fi.absolutePath() :
                            "";
                     int len = from.length();
@@ -463,7 +455,7 @@ QString RenameImagesWidget::oldToNewName(BatchProcessImagesItem* item,
     if (!useExtraSymbols)
     {
         int numDigits = 1;
-        int count = m_listView->childCount();
+        int count = m_listView->topLevelItemCount();
         while (count > 0)
         {
             numDigits++;
@@ -480,23 +472,24 @@ QString RenameImagesWidget::oldToNewName(BatchProcessImagesItem* item,
 
         newName += QString::fromLatin1(".") + fi.extension();
     }
-    
+
     return newName;
 }
 
 void RenameImagesWidget::slotGotPreview(const KFileItem*, const QPixmap& pix)
 {
-    m_pixLabel->setPixmap(pix);    
+    m_pixLabel->setPixmap(pix);
 }
 
 void RenameImagesWidget::slotStart()
 {
     m_timer->start(0, true);
 
-    m_listView->setSelected(m_listView->firstChild(), true);
-    m_listView->ensureItemVisible(m_listView->firstChild());
+    QTreeWidgetItem* item = m_listView->topLevelItem(0);
+    m_listView->setCurrentItem(item);
+    m_listView->scrollToItem(item);
 
-    m_progress->setTotalSteps(m_listView->childCount());
+    m_progress->setTotalSteps(m_listView->topLevelItemCount());
     m_progress->setProgress(0);
     m_progress->show();
 
@@ -513,7 +506,7 @@ void RenameImagesWidget::slotAbort()
 
 void RenameImagesWidget::slotNext()
 {
-    Q3ListViewItem* it = m_listView->selectedItem();
+    QTreeWidgetItem* it = m_listView->selectedItems().first();
     if (!it)
     {
         slotAbort();
@@ -528,7 +521,7 @@ void RenameImagesWidget::slotNext()
 
     bool skip      = false;
     bool overwrite = false;
-    
+
     if (!m_overwriteAll)
     {
         struct stat info;
@@ -591,12 +584,12 @@ void RenameImagesWidget::slotNext()
     {
         // Get the src info
         KIPI::ImageInfo srcInfo = m_interface->info(src);
-        
+
         if (::rename(QFile::encodeName(src.path()),
                      QFile::encodeName(dst.path())) == 0)
         {
             srcInfo.setTitle(dst.fileName());
-            
+
             item->changeResult(i18n("OK"));
         }
         else
@@ -607,10 +600,11 @@ void RenameImagesWidget::slotNext()
 
     m_progress->setProgress(m_progress->progress() + 1);
 
-    if (it->nextSibling())
+    it = m_listView->itemBelow(it);
+    if (it)
     {
-        m_listView->setSelected(it->nextSibling(), true);
-        m_listView->ensureItemVisible(it->nextSibling());
+        m_listView->setCurrentItem(it);
+        m_listView->scrollToItem(it);
         m_timer->start(0, true);
     }
 }
@@ -637,15 +631,15 @@ void RenameImagesWidget::slotAddImages()
 
 void RenameImagesWidget::slotRemoveImage()
 {
-    if (!m_listView->selectedItem())
+    if (m_listView->selectedItems().isEmpty())
         return;
 
     BatchProcessImagesItem* item =
-        static_cast<BatchProcessImagesItem*>(m_listView->selectedItem());
+        static_cast<BatchProcessImagesItem*>(m_listView->selectedItems().first());
     delete item;
 
     m_pixLabel->clear();
-    
+
     updateListing();
 }
 
