@@ -23,36 +23,36 @@
 #include "resizeimagesdialog.h"
 #include "resizeimagesdialog.moc"
 
-// Include files for Qt
+// Qt includes
 
-#include <q3groupbox.h>
-#include <qlabel.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qimage.h>
+#include <QGroupBox>
+#include <QCheckBox>
+#include <QImage>
+#include <QLabel>
+#include <QPushButton>
 
-// Include files for KDE
+// KDE includes
 
-#include <klocale.h>
+#include <kapplication.h>
+#include <kcolorbutton.h>
+#include <kcombobox.h>
 #include <kconfig.h>
+#include <khelpmenu.h>
+#include <kiconloader.h>
+#include <klocale.h>
+#include <kmenu.h>
 #include <kmessagebox.h>
 #include <knuminput.h>
 #include <kprocess.h>
-#include <kcolorbutton.h>
-#include <kapplication.h>
-#include <khelpmenu.h>
-#include <kiconloader.h>
-#include <kmenu.h>
 #include <ktoolinvocation.h>
 
 // Local includes
 
 #include "dialogutils.h"
 #include "kpaboutdata.h"
+#include "outputdialog.h"
 #include "pluginsversion.h"
 #include "resizeoptionsdialog.h"
-#include "outputdialog.h"
 
 namespace KIPIBatchProcessImagesPlugin
 {
@@ -93,20 +93,20 @@ ResizeImagesDialog::ResizeImagesDialog( KUrl::List urlList, KIPI::Interface* int
     m_Type->insertItem(i18n("Non-Proportional"));       // 2
     m_Type->insertItem(i18n("Prepare to Print"));       // 3
     m_Type->setCurrentText(i18n("Proportional (1 dim.)"));
-    whatsThis = i18n("<p>Select here the image-resize type.");
+    whatsThis = i18n("<p>Select here the image-resize type.</p>");
     whatsThis = whatsThis + i18n("<p><b>Proportional (1 dim.)</b>: standard auto-resizing using one dimension. "
                                  "The width or the height of the images will be automatically "
                                  "selected, depending on the images' orientations. "
-                                 "The images' aspect ratios are preserved.");
+                                 "The images' aspect ratios are preserved.</p>");
     whatsThis = whatsThis + i18n("<p><b>Proportional (2 dim.)</b>: auto-resizing using two dimensions. "
                                  "The images' aspect ratio are preserved. You can use this, for example, "
-                                 "to adapt your images' sizes to your screen size.");
+                                 "to adapt your images' sizes to your screen size.</p>");
     whatsThis = whatsThis + i18n("<p><b>Non proportional</b>: non-proportional resizing using two dimensions. "
-                                 "The images' aspect ratios are not preserved.");
+                                 "The images' aspect ratios are not preserved.</p>");
     whatsThis = whatsThis + i18n("<p><b>Prepare to print</b>: prepare the image for photographic printing. "
                                  "The user can set the print resolution and the photographic paper size. "
                                  "The target images will be adapted to the specified dimensions "
-                                 "(included the background size, margin size, and background color).");
+                                 "(included the background size, margin size, and background color).</p>");
 
     m_Type->setWhatsThis(whatsThis );
 
@@ -174,13 +174,13 @@ void ResizeImagesDialog::slotOptionsClicked(void)
        {
        if (Type == 0) // Proportional (1 dim.)
           {
-	  m_quality = optionsDialog->m_quality->value();	  
+	  m_quality = optionsDialog->m_quality->value();
           m_size = optionsDialog->m_size->value();
           m_resizeFilter = optionsDialog->m_resizeFilter->currentText();
           }
        if (Type == 1) // Proportional (2 dim.)
           {
-	  m_quality = optionsDialog->m_quality->value();	  
+	  m_quality = optionsDialog->m_quality->value();
           m_Width = optionsDialog->m_Width->value();
           m_Height = optionsDialog->m_Height->value();
           m_bgColor = optionsDialog->m_button_bgColor->color();
@@ -189,14 +189,14 @@ void ResizeImagesDialog::slotOptionsClicked(void)
           }
        if (Type == 2) // Non-proportional
           {
-	  m_quality = optionsDialog->m_quality->value();	  
+	  m_quality = optionsDialog->m_quality->value();
           m_fixedWidth = optionsDialog->m_fixedWidth->value();
           m_fixedHeight = optionsDialog->m_fixedHeight->value();
           m_resizeFilter = optionsDialog->m_resizeFilter->currentText();
           }
        if (Type == 3) // Prepare to print
           {
-	  m_quality = optionsDialog->m_quality->value();	  
+	  m_quality = optionsDialog->m_quality->value();
           m_paperSize = optionsDialog->m_paperSize->currentText();
           m_printDpi = optionsDialog->m_printDpi->currentText();
           m_customXSize = optionsDialog->m_customXSize->value();
@@ -219,7 +219,7 @@ void ResizeImagesDialog::readSettings(void)
     KConfig config("kipirc");
     KConfigGroup group = config.group("ResizeImages Settings");
 
-    m_Type->setCurrentItem(group.readEntry("ResiseType", 3)); // Prepare to print per default.
+    m_Type->setCurrentIndex(group.readEntry("ResiseType", 3)); // Prepare to print per default.
     m_size = group.readEntry("Size", 640);
     m_resizeFilter = group.readEntry("ResizeFilter", "Lanczos");
 
@@ -246,7 +246,7 @@ void ResizeImagesDialog::readSettings(void)
     else
        m_customSettings = false;
 
-    m_overWriteMode->setCurrentItem(group.readEntry("OverWriteMode", 2));  // 'Rename' per default...
+    m_overWriteMode->setCurrentIndex(group.readEntry("OverWriteMode", 2));  // 'Rename' per default...
 
     if (group.readEntry("RemoveOriginal", "false") == "true")
         m_removeOriginal->setChecked( true );
@@ -376,11 +376,11 @@ void ResizeImagesDialog::initProcess(KProcess* proc, BatchProcessImagesItem *ite
 
           *proc << item->pathSrc() + "[0]";
 
-          // ImageMagick composite program do not preserve exif data from original. 
+          // ImageMagick composite program do not preserve exif data from original.
           // Need to use "-profile" option for that.
-          
+
           *proc << "-profile" << item->pathSrc();
-          
+
           Temp2 = "xc:rgb(" + Temp.setNum(m_bgColor.red()) + ",";
           Temp2.append(Temp.setNum(m_bgColor.green()) + ",");
           Temp2.append(Temp.setNum(m_bgColor.blue()) + ")");
@@ -405,7 +405,7 @@ void ResizeImagesDialog::initProcess(KProcess* proc, BatchProcessImagesItem *ite
              {
              *proc << "-filter" << m_resizeFilter;
              }
-            
+
           *proc << "-quality";
           QString Temp3;
           Temp3.setNum(m_quality);
@@ -503,9 +503,9 @@ void ResizeImagesDialog::initProcess(KProcess* proc, BatchProcessImagesItem *ite
           Temp2.append(Temp.setNum(m_backgroundColor.blue()) + ")");
           *proc << Temp2;
 
-          // ImageMagick composite program do not preserve exif data from original. 
+          // ImageMagick composite program do not preserve exif data from original.
           // Need to use "-profile" option for that.
-          
+
           *proc << "-profile" << item->pathSrc();
 
           *proc << "-resize" << targetBackgroundSize + "!";
@@ -564,4 +564,4 @@ bool ResizeImagesDialog::ResizeImage( int &w, int &h, int SizeFactor)
     return (valRet);  // Return true is image increased, else true.
 }
 
-}  // NameSpace KIPIBatchProcessImagesPlugin
+}  // namespace KIPIBatchProcessImagesPlugin
