@@ -39,7 +39,7 @@
     ADOBE DNG CONVERTER: ftp://ftp.adobe.com/pub/adobe/photoshop/cameraraw/win/4.x
 */
 
-// Qt includes.
+// Qt includes
 
 #include <QImage>
 #include <QString>
@@ -49,16 +49,16 @@
 #include <QIODevice>
 #include <QTemporaryFile>
 
-// KDE includes.
+// KDE includes
 
 #include <kdebug.h>
 #include <kzip.h>
 
-// Libkexiv2 includes.
+// Libkexiv2 includes
 
 #include <libkexiv2/kexiv2.h>
 
-// Local includes.
+// Local includes
 
 #include "dngwriterprivate.h"
 #include "dngwriterhost.h"
@@ -622,23 +622,23 @@ int DNGWriter::convert()
             if (meta.getExifTagLong("Exif.GPSInfo.GPSVersionID", val))           exif->fGPSVersionID             = (uint32)val;
             if (meta.getExifTagLong("Exif.GPSInfo.GPSAltitudeRef", val))         exif->fGPSAltitudeRef           = (uint32)val;
             if (meta.getExifTagLong("Exif.GPSInfo.GPSDifferential", val))        exif->fGPSDifferential          = (uint32)val;
-        }
 
-        // Markernote backup.
+            // Markernote backup.
 
-        QByteArray mkrnts = meta.getExifTagData("Exif.Photo.MakerNote");
-        if (!mkrnts.isEmpty())
-        {
-            kDebug( 51000 ) << "DNGWriter: Backup Makernote (" << mkrnts.size() << " bytes)" << endl;
+            QByteArray mkrnts = meta.getExifTagData("Exif.Photo.MakerNote");
+            if (!mkrnts.isEmpty())
+            {
+                kDebug( 51000 ) << "DNGWriter: Backup Makernote (" << mkrnts.size() << " bytes)" << endl;
 
-            dng_memory_allocator memalloc(gDefaultDNGMemoryAllocator);
-            dng_memory_stream stream(memalloc);
-            stream.Put(mkrnts.data(), mkrnts.size());
-            AutoPtr<dng_memory_block> block(host.Allocate(mkrnts.size()));
-            stream.SetReadPosition(0);
-            stream.Get(block->Buffer(), mkrnts.size());
-            negative->SetMakerNote(block);
-            negative->SetMakerNoteSafety(true);
+                dng_memory_allocator memalloc(gDefaultDNGMemoryAllocator);
+                dng_memory_stream stream(memalloc);
+                stream.Put(mkrnts.data(), mkrnts.size());
+                AutoPtr<dng_memory_block> block(host.Allocate(mkrnts.size()));
+                stream.SetReadPosition(0);
+                stream.Get(block->Buffer(), mkrnts.size());
+                negative->SetMakerNote(block);
+                negative->SetMakerNoteSafety(true);
+            }
         }
 
         if (d->backupOriginalRawFile)
@@ -801,6 +801,20 @@ int DNGWriter::convert()
         writer.WriteDNG(host, filestream, *negative.Get(), thumbnail, 
                         d->jpegLossLessCompression ? ccJPEG : ccUncompressed,
                         &previewList);
+
+        // -----------------------------------------------------------------------------------------
+        // Metadata transfert using Exiv2. Used to restore Makernote offset.
+
+        kDebug( 51000 ) << "DNGWriter: Backup meta-data using Exiv2" << endl;
+        KExiv2 dngMeta(dngFilePath);
+
+        if (meta.load(inputFile()))
+        {
+            meta.setWriteRawFiles(true);
+            meta.setIptc(dngMeta.getIptc());
+            meta.setXmp(dngMeta.getXmp());
+            meta.save(dngFilePath);
+        }
     }
 
     catch (const dng_exception &exception)
