@@ -8,6 +8,7 @@
  *
  * Copyright (C) 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
  * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,14 +25,14 @@
 #include "picasawebtalker.h"
 #include "picasawebtalker.moc"
 
-// C++ includes.
+// C++ includes
 
 #include <cstring>
 #include <cstdio>
 #include <cstdlib>
 #include <string>
 
-// Qt includes.
+// Qt includes
 
 #include <QByteArray>
 #include <QDomDocument>
@@ -44,7 +45,7 @@
 #include <QStringList>
 #include <QUrl>
 
-// KDE includes.
+// KDE includes
 
 #include <kapplication.h>
 #include <kcodecs.h>
@@ -59,11 +60,11 @@
 #include <kstandarddirs.h>
 #include <kurl.h>
 
-// LibKExiv2 includes.
+// LibKExiv2 includes
 
 #include <libkexiv2/kexiv2.h>
 
-// LibKDcraw includes.
+// LibKDcraw includes
 
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
@@ -72,7 +73,7 @@
 #include <libkdcraw/dcrawbinary.h>
 #endif
 
-// Local includes.
+// Local includes
 
 #include "mpform.h"
 #include "picasawebitem.h"
@@ -416,7 +417,6 @@ bool PicasawebTalker::addPhoto(const QString& photoPath, FPhotoInfo& info,
 
     QString     postUrl     = "http://www.picasaweb.google.com/data/feed/api/user/" + 
                               QUrl::toPercentEncoding(m_username) + "/albumid/" + album_id;
-    QString     path        = postUrl;
     QString     auth_string = "GoogleLogin auth=" + m_token;
     QStringList headers;
     MPForm      form;
@@ -438,7 +438,6 @@ bool PicasawebTalker::addPhoto(const QString& photoPath, FPhotoInfo& info,
 
     // save the tags for this photo in to the tags hashmap
     tags_map.insert(info.title, info.tags);
-    QImage image;
 
     // Check if RAW file.
 #if KDCRAW_VERSION < 0x000400
@@ -447,40 +446,54 @@ bool PicasawebTalker::addPhoto(const QString& photoPath, FPhotoInfo& info,
     QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
 #endif
     QFileInfo fileInfo(photoPath);
-    if (rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper()))
-        KDcrawIface::KDcraw::loadDcrawPreview(image, photoPath);
-    else
-        image.load(photoPath);
+    bool isRAW = rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper());
 
-    if (!image.isNull())
+    if (isRAW || rescale)
     {
-        path = KStandardDirs::locateLocal("tmp", QFileInfo(photoPath).baseName().trimmed() + ".jpg");
+        // use temporary file for upload
+        QImage image;
+        if (isRAW)
+            KDcrawIface::KDcraw::loadDcrawPreview(image, photoPath);
+        else
+            image.load(photoPath);
+
+        QString tmpPath = KStandardDirs::locateLocal("tmp", QFileInfo(photoPath).baseName().trimmed() + ".jpg");
 
         if (rescale && (image.width() > maxDim || image.height() > maxDim))
             image = image.scaled(maxDim, maxDim, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 
-        image.save(path, "JPEG", imageQuality);
+        image.save(tmpPath, "JPEG", imageQuality);
 
         // Restore all metadata.
-
         KExiv2Iface::KExiv2 exiv2Iface;
 
         if (exiv2Iface.load(photoPath))
         {
             exiv2Iface.setImageProgramId(QString("Kipi-plugins"), QString(kipiplugins_version));
             exiv2Iface.setImageDimensions(image.size());
-            exiv2Iface.save(path);
+            exiv2Iface.save(tmpPath);
         }
         else
         {
-            kWarning(51000) << "(picasawebExport::Image doesn't have exif data)" << endl;
+            kWarning(51000) << "Image " << photoPath << " has no exif data";
         }
 
-        kDebug( 51000 ) << "Resizing and saving to temp file: " << path << endl;
-    }
+        kDebug( 51000 ) << "Resizing and saving to temp file: " << tmpPath;
 
-    if (!form.addFile("photo", path))
-        return false;
+        if (!form.addFile("photo", tmpPath))
+        {
+            QFile::remove(tmpPath);
+            return false;
+        }
+
+        QFile::remove(tmpPath);
+    }
+    else
+    {
+        // use original file
+        if (!form.addFile("photo", photoPath))
+            return false;
+    }
 
     form.finish();
 
@@ -564,9 +577,9 @@ void PicasawebTalker::slotError(const QString & error)
         case 3:
             transError=i18n("General upload failure");break;
         case 4:
-            transError=i18n("Filesize was zero");break;
+            transError=i18n("File-size was zero");break;
         case 5:
-            transError=i18n("Filetype was not recognised");break;
+            transError=i18n("File-type was not recognized");break;
         case 6:
             transError=i18n("User exceeded upload limit");break;
         case 96:
@@ -574,7 +587,7 @@ void PicasawebTalker::slotError(const QString & error)
         case 97:
             transError=i18n("Missing signature"); break;
         case 98:
-            transError=i18n("Login Failed / Invalid auth token"); break;
+            transError=i18n("Login failed / Invalid auth token"); break;
         case 100:
             transError=i18n("Invalid API Key"); break;
         case 105:
@@ -590,12 +603,12 @@ void PicasawebTalker::slotError(const QString & error)
         case 115:
             transError=i18n("Invalid XML-RPC Method Call");break;
         case 116:
-            transError=i18n("The POST method is now required for all setters"); break;
+            transError=i18n("The POST method is now required for all setters."); break;
         default:
             transError=i18n("Unknown error");
     };
 
-    KMessageBox::error(kapp->activeWindow(), i18n("Error Occured: %1\n We can not proceed further",transError + error));
+    KMessageBox::error(kapp->activeWindow(), i18n("Error occurred: %1\nUnable to proceed further.",transError + error));
 }
 
 void PicasawebTalker::slotResult(KJob *job)
@@ -758,10 +771,7 @@ void PicasawebTalker::parseResponseListAlbums(const QByteArray &data)
 
                     if(detailsNode.nodeName() == "title")
                     {
-                        album_title = "Not fetched";
-
-                        if(detailsNode.toElement().attribute("type")=="text")
-                            album_title = detailsNode.toElement().text();
+                        album_title = detailsNode.toElement().text();
 
                         //this is what is obtained from data.
                         fps.title = album_title;
@@ -784,7 +794,7 @@ void PicasawebTalker::parseResponseListAlbums(const QByteArray &data)
 
     if (!success)
     {
-        emit signalGetAlbumsListFailed(i18n("Failed to fetch photoSets List"));
+        emit signalGetAlbumsListFailed(i18n("Failed to fetch photo-set list"));
         m_albumsList = NULL;
     }
     else
