@@ -8,6 +8,7 @@
  *
  * Copyright (C) 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
  * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,7 +25,7 @@
 #include "picasawebwindow.h"
 #include "picasawebwindow.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QProgressDialog>
 #include <QCloseEvent>
@@ -32,7 +33,7 @@
 #include <QLinkedList>
 #include <QStringList>
 
-// KDE includes.
+// KDE includes
 
 #include <kapplication.h>
 #include <kdebug.h>
@@ -49,12 +50,12 @@
 #include <ksimpleconfig.h>
 #include <kwallet.h>
 
-// LibKIPI includes.
+// LibKIPI includes
 
 #include <libkipi/interface.h>
 #include <ktoolinvocation.h>
 
-// Local includes.
+// Local includes
 
 #include "imagedialog.h"
 #include "kpaboutdata.h"
@@ -106,13 +107,14 @@ PicasawebWindow::PicasawebWindow(KIPI::Interface* interface, const QString &tmpF
 
     // ------------------------------------------------------------
 
-    m_about = new KIPIPlugins::KPAboutData(ki18n("Picasaweb Export"),
+    m_about = new KIPIPlugins::KPAboutData(ki18n("PicasaWeb Export"),
                                            0,
                                            KAboutData::License_GPL,
-                                           ki18n("A Kipi plugin to export image collection to "
-                                                 "Picasaweb web service."),
+                                           ki18n("A Kipi plugin to export image collections to "
+                                                 "PicasaWeb web service."),
                                            ki18n( "(c) 2007-2009, Vardhman Jain\n"
-                                           "(c) 2008-2009, Gilles Caulier" ));
+                                           "(c) 2008-2009, Gilles Caulier\n"
+                                           "(c) 2009, Luka Renko" ));
 
     m_about->addAuthor(ki18n( "Vardhman Jain" ), ki18n("Author and maintainer"),
                        "Vardhman at gmail dot com");
@@ -120,6 +122,9 @@ PicasawebWindow::PicasawebWindow(KIPI::Interface* interface, const QString &tmpF
     m_about->addAuthor(ki18n( "Gilles Caulier" ), ki18n("Developer"),
                        "caulier dot gilles at gmail dot com");
 
+    m_about->addAuthor(ki18n( "Luka Renko" ), ki18n("Developer"),
+                       "lure at kubuntu dot org");
+
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeAction(helpMenu->menu()->actions().first());
     QAction *handbook   = new QAction(i18n("Handbook"), this);
@@ -300,17 +305,15 @@ void PicasawebWindow::slotHelp()
 
 void PicasawebWindow::slotGetAlbumsListSucceeded()
 {
+    m_albumsListComboBox->clear();
     if (m_talker && m_talker->m_albumsList)
     {
         QLinkedList <PicasaWebAlbum> *list = m_talker->m_albumsList;
-        m_albumsListComboBox->clear();
         QLinkedList<PicasaWebAlbum>::iterator it = list->begin();
-        int index = 0;
         while(it != list->end())
         {
             PicasaWebAlbum pwa=*it;
-            QString name = pwa.title;
-            m_albumsListComboBox->insertItem(index++, name);
+            m_albumsListComboBox->addItem(pwa.title, pwa.id);
             it++;
         }
     }
@@ -369,6 +372,8 @@ void PicasawebWindow::slotCreateNewAlbum()
     {
         if (dlg->m_isPublicRadioButton->isChecked())
             access = QString("public");
+        else if (dlg->m_isProtectedRadioButton->isChecked())
+            access = QString("protected");
         else
             access = QString("private");
 
@@ -418,15 +423,29 @@ void PicasawebWindow::slotAddPhotos()
 
 void PicasawebWindow::slotUploadImages()
 {
-   if(m_widget->m_currentSelectionButton->isChecked())
-   {
+
+    if (m_albumsListComboBox->currentIndex() == -1) 
+    {
+        KMessageBox::error(this, 
+            i18n("No album selected - please create and select album."));
+        return;
+    }
+    m_currentAlbumId = m_albumsListComboBox->itemData(
+                            m_albumsListComboBox->currentIndex()).toString();
+
+    if (m_widget->m_currentSelectionButton->isChecked())
+    {
         delete m_urls;
 
         m_urls=new KUrl::List(m_interface->currentSelection().images());
-   }
+    }
 
-   if (m_urls == NULL || m_urls->isEmpty())
+    if (m_urls == NULL || m_urls->isEmpty()) 
+    {
+        KMessageBox::error(this, 
+            i18n("Nothing to upload - please select photos to upload."));
         return;
+    }
 
     typedef QPair<QString,FPhotoInfo> Pair;
 
@@ -507,25 +526,8 @@ void PicasawebWindow::slotAddPhotoNext()
 /*    int upload_image_size;
     int upload_image_quality;*/
 
-    // Get the albums' Id from the name.
-    QString albumId = "";
-    QString selectedAlbumName = m_albumsListComboBox->currentText();
-
-    QLinkedList<PicasaWebAlbum>::iterator it = m_talker->m_albumsList->begin();
-    while(it != m_talker->m_albumsList->end()) 
-    {
-       PicasaWebAlbum pwa=*it;
-       QString name = pwa.title;
-       if (name == selectedAlbumName) 
-        {
-           albumId = pwa.id;
-           break;
-       }
-       it++;
-    }
-
     bool res = m_talker->addPhoto(pathComments.first,          //the file path
-                                  info, albumId,
+                                  info, m_currentAlbumId,
                                   m_resizeCheckBox->isChecked(),
                                   m_dimensionSpinBox->value(), m_imageQualitySpinBox->value());
     if (!res)
@@ -551,7 +553,7 @@ void PicasawebWindow::slotAddPhotoSucceeded()
 void PicasawebWindow::slotAddPhotoFailed(const QString& msg)
 {
     if ( KMessageBox::warningContinueCancel(this,
-           i18n("Failed to upload photo into Picasaweb. %1\nDo you want to continue?",
+           i18n("Failed to upload photo to PicasaWeb. %1\nDo you want to continue?",
                 msg )) != KMessageBox::Continue)
     {
         m_uploadQueue.clear();
@@ -572,6 +574,7 @@ void PicasawebWindow::slotAddPhotoFailed(const QString& msg)
 void PicasawebWindow::slotGetAlbumsListFailed(const QString& /*msg*/)
 {
     // Raise some errors
+    m_albumsListComboBox->clear();
 }
 
 void PicasawebWindow::slotAddPhotoCancel()
