@@ -21,10 +21,13 @@
  * ============================================================ */
 
 #include "wizard.moc"
+
 // STD
+
 #include <memory>
 
 // Qt includes
+
 #include <QFileInfo>
 #include <QPainter>
 #include <QPalette>
@@ -33,6 +36,7 @@
 #include <QPrintDialog>
 
 // KDE includes
+
 #include <kapplication.h>
 #include <kconfigdialogmanager.h>
 #include <khelpmenu.h>
@@ -45,13 +49,16 @@
 #include <kdebug.h>
 
 // libkipi includes
+
 #include <libkipi/imagecollectionselector.h>
 #include <libkipi/interface.h>
 
 // libkexiv2 includes
+
 #include <libkexiv2/kexiv2.h>
 
 // Local includes
+
 #include "kpaboutdata.h"
 #include "ui_croppage.h"
 #include "ui_infopage.h"
@@ -63,11 +70,12 @@
 namespace KIPIPrintImagesPlugin
 {
 
-
   template <class Ui_Class>
+
   class WizardPage : public QWidget, public Ui_Class
   {
     public:
+
       WizardPage ( KAssistantDialog* dialog, const QString& title )
           : QWidget ( dialog )
       {
@@ -202,11 +210,13 @@ namespace KIPIPrintImagesPlugin
 
     connect ( d->mPhotoPage->BtnPreviewPageUp, SIGNAL ( clicked ( void ) ),
               this, SLOT ( BtnPreviewPageUp_clicked ( void ) ) );
+
     connect ( d->mPhotoPage->BtnPreviewPageDown, SIGNAL ( clicked ( void ) ),
               this, SLOT ( BtnPreviewPageDown_clicked ( void ) ) );
 
     connect ( d->mCropPage->BtnCropPrev, SIGNAL ( clicked() ),
               this, SLOT ( BtnCropPrev_clicked() ) );
+
     connect ( d->mCropPage->BtnCropNext, SIGNAL ( clicked() ),
               this, SLOT ( BtnCropNext_clicked() ) );
 
@@ -714,7 +724,7 @@ namespace KIPIPrintImagesPlugin
 
       default:
       {
-        kDebug() << "Initializing Unsupported page layouts\n";
+        kDebug(51000) << "Initializing Unsupported page layouts\n";
         // We don't support this page size yet.  Just create a default page.
         TPhotoSize *p;
         p = new TPhotoSize;
@@ -807,9 +817,9 @@ namespace KIPIPrintImagesPlugin
   }
 
 
-  const float FONT_HEIGHT_RATIO = 0.8;
+  const float FONT_HEIGHT_RATIO = 0.8F;
 
-  void Wizard::printCaption ( QPainter &p, TPhoto*/*photo*/, int captionW, int captionH, QString caption )
+  void Wizard::printCaption ( QPainter &p, TPhoto* /*photo*/, int captionW, int captionH, QString caption )
   {
     // PENDING anaselli TPhoto*photo will be needed to add a per photo caption management
     QStringList captionByLines;
@@ -1467,7 +1477,7 @@ namespace KIPIPrintImagesPlugin
     if ( pageSize > A6 )
     {
       KMessageBox::information ( this,
-                                 i18n ( "Don't forget to set up the correct page size according to your printer settings" ),
+                                 i18n ( "Do not forget to set the correct page size according to your printer settings." ),
                                  i18n ( "Page size settings" ), "pageSizeInfo" );
     }
   }
@@ -1477,12 +1487,12 @@ namespace KIPIPrintImagesPlugin
     if ( before )
     {
       saveSettings ( before->name() );
-      kDebug() << " before " << before->name();
+      kDebug(51000) << " before " << before->name();
     }
     if ( current )
     {
       readSettings ( current->name() );
-      kDebug() << " current " << current->name();
+      kDebug(51000) << " current " << current->name();
     }
     if ( current->name() == i18n ( introPageName ) )
     {
@@ -1506,7 +1516,7 @@ namespace KIPIPrintImagesPlugin
         {
           this->nextButton()->setEnabled ( true );
         }
-      kDebug() << "CCCC" << endl;
+      kDebug(51000) << "CCCC" << endl;
 #endif
     }
     else if ( current->name() == i18n ( photoPageName ) )
@@ -1979,7 +1989,7 @@ namespace KIPIPrintImagesPlugin
     if ( m_kjobviewer->isChecked() )
       if ( !m_Proc->start() )
         kdDebug ( 51000 ) << "Error running kjobviewr\n";
-    LblPrintProgress->setText ( i18n ( "Complete.  Click Finish to exit the Print Wizard." ) );
+    LblPrintProgress->setText ( i18n ( "Complete. Click Finish to exit the Print Wizard." ) );
 #endif
   }
 
@@ -2021,7 +2031,7 @@ namespace KIPIPrintImagesPlugin
       if ( QFile::exists ( filename ) )
       {
         int result = KMessageBox::warningYesNoCancel ( this,
-                     i18n ( "The following file will be overwritten. Do you want to overwrite this file?" ) +
+                     i18n ( "The following file will be overwritten. Are you sure you want to overwrite it?" ) +
                      "\n\n" + filename );
         if ( result == KMessageBox::No )
           saveFile = false;
@@ -2061,7 +2071,7 @@ namespace KIPIPrintImagesPlugin
       if ( m_kjobviewer->isChecked() )
         if ( !m_Proc->start() )
           kdDebug ( 51000 ) << "Error launching kjobviewr\n";
-      LblPrintProgress->setText ( i18n ( "Complete.  Click Finish to exit the Print Wizard." ) );
+      LblPrintProgress->setText ( i18n ( "Complete. Click Finish to exit the Print Wizard." ) );
     }
 #endif
     return files;
@@ -2075,7 +2085,7 @@ namespace KIPIPrintImagesPlugin
       {
         if ( QFile::remove ( *it ) == false )
         {
-          KMessageBox::sorry ( this, i18n ( "Could not remove the Gimp's temporary files." ) );
+          KMessageBox::sorry ( this, i18n ( "Could not remove the GIMP's temporary files." ) );
           break;
         }
       }
@@ -2085,7 +2095,7 @@ namespace KIPIPrintImagesPlugin
 //TODO not needed at the moment maybe we can remove it
   void Wizard::PageRemoved ( KPageWidgetItem *page )
   {
-    kDebug() << page->name();
+    kDebug(51000) << page->name();
   }
 
   void Wizard::crop_selection ( int )
@@ -2143,7 +2153,7 @@ namespace KIPIPrintImagesPlugin
           break;
       }
 
-      kDebug() << " page size " << d->m_pageSize
+      kDebug(51000) << " page size " << d->m_pageSize
       << " printer: " << printer.paperSize() << " A6: " << QPrinter::A6 << endl;
 
       if ( d->mInfoPage->m_fullbleed->isChecked() )
@@ -2153,7 +2163,7 @@ namespace KIPIPrintImagesPlugin
       }
 
       bool wantToPrint = dialog->exec();
-      kDebug() << "full page " << printer.fullPage() ;
+      kDebug(51000) << "full page " << printer.fullPage() ;
 
       if ( !wantToPrint )
       {
@@ -2161,7 +2171,7 @@ namespace KIPIPrintImagesPlugin
       }
 
       printPhotos ( d->m_photos, s->layouts, printer );
-      kDebug() << "paper page " << dialog->printer()->paperSize() ;
+      kDebug(51000) << "paper page " << dialog->printer()->paperSize() ;
     }
     else if ( d->mInfoPage->RdoOutputFile->isChecked() )
     {
@@ -2190,7 +2200,7 @@ namespace KIPIPrintImagesPlugin
       if ( !launchExternalApp ( prog, args ) )
       {
         KMessageBox::sorry ( this,
-                             i18n ( "There was an error launching the Gimp. Please make sure it is properly installed." ),
+                             i18n ( "There was an error launching the GIMP. Please make sure it is properly installed." ),
                              i18n ( "KIPI" ) );
         return;
       }
@@ -2204,5 +2214,4 @@ namespace KIPIPrintImagesPlugin
     KAssistantDialog::accept();
   }
 
-
 } // namespace
