@@ -24,7 +24,7 @@
 #include "batchdialog.h"
 #include "batchdialog.moc"
 
-// C ANSI includes.
+// C ANSI includes
 
 extern "C"
 {
@@ -33,11 +33,11 @@ extern "C"
 #include <unistd.h>
 }
 
-// C++ includes.
+// C++ includes
 
 #include <cstdio>
 
-// Qt includes.
+// Qt includes
 
 #include <QCloseEvent>
 #include <QFile>
@@ -50,7 +50,7 @@ extern "C"
 #include <QTimer>
 #include <QTreeWidgetItemIterator>
 
-// KDE includes.
+// KDE includes
 
 #include <kapplication.h>
 #include <kconfig.h>
@@ -66,17 +66,17 @@ extern "C"
 #include <kstandarddirs.h>
 #include <ktoolinvocation.h>
 
-// LibKDcraw includes.
+// LibKDcraw includes
 
 #include <libkdcraw/version.h>
 #include <libkdcraw/dcrawsettingswidget.h>
 
-// LibKIPI includes.
+// LibKIPI includes
 
 #include <libkipi/interface.h>
 #include <libkipi/imageinfo.h>
 
-// Local includes.
+// Local includes
 
 #include "actions.h"
 #include "actionthread.h"
@@ -145,15 +145,15 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
 
     setButtons(Help | Default | Apply | Close | User1 | User2);
     setDefaultButton(KDialog::Close);
-    setButtonToolTip(Close, i18n("Exit Raw Converter"));
-    setCaption(i18n("Raw Images Batch Converter"));
+    setButtonToolTip(Close, i18n("Exit RAW Converter"));
+    setCaption(i18n("RAW Image Batch Converter"));
     setModal(false);
     setButtonIcon(User1, KIcon("list-add"));
     setButtonText(User1, i18n("&Add"));
-    setButtonToolTip(User1, i18n("Add new Raw files to the list"));
+    setButtonToolTip(User1, i18n("Add new RAW files to the list"));
     setButtonIcon(User2, KIcon("list-remove"));
     setButtonText(User2, i18n("&Remove"));
-    setButtonToolTip(User2, i18n("Remove selected Raw files from the list"));
+    setButtonToolTip(User2, i18n("Remove selected RAW files from the list"));
 
     d->page = new QWidget( this );
     setMainWidget( d->page );
@@ -173,7 +173,7 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
 
     QStringList labels;
     labels.append( i18n("Thumbnail") );
-    labels.append( i18n("Raw File") );
+    labels.append( i18n("RAW File") );
     labels.append( i18n("Target File") );
     labels.append( i18n("Camera") );
     d->listView->setHeaderLabels(labels);
@@ -211,7 +211,7 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
     d->about = new KIPIPlugins::KPAboutData(ki18n("RAW Image Converter"),
                    0,
                    KAboutData::License_GPL,
-                   ki18n("A Kipi plugin to batch convert Raw images"),
+                   ki18n("A Kipi plugin to batch convert RAW images"),
                    ki18n("(c) 2003-2005, Renchi Raju\n"
                          "(c) 2006-2009, Gilles Caulier"));
 
@@ -350,6 +350,9 @@ void BatchDialog::readSettings()
     d->decodingSettingsBox->setUseCACorrection(group.readEntry("EnableCACorrection", false));
     d->decodingSettingsBox->setcaRedMultiplier(group.readEntry("caRedMultiplier", 1.0));
     d->decodingSettingsBox->setcaBlueMultiplier(group.readEntry("caBlueMultiplier", 1.0));
+#if KDCRAW_VERSION >= 0x000500
+    d->decodingSettingsBox->setAutoBrightness(group.readEntry("AutoBrightness", true));
+#endif
 
     d->decodingSettingsBox->setQuality(
         (KDcrawIface::RawDecodingSettings::DecodingQuality)group.readEntry("Decoding Quality",
@@ -398,7 +401,9 @@ void BatchDialog::saveSettings()
     group.writeEntry("caBlueMultiplier", d->decodingSettingsBox->caBlueMultiplier());
     group.writeEntry("Decoding Quality", (int)d->decodingSettingsBox->quality());
     group.writeEntry("Output Color Space", (int)d->decodingSettingsBox->outputColorSpace());
-
+#if KDCRAW_VERSION >= 0x000500
+    group.writeEntry("AutoBrightness", d->decodingSettingsBox->useAutoBrightness());
+#endif
     group.writeEntry("Output Format", (int)d->saveSettingsBox->fileFormat());
     group.writeEntry("Conflict", (int)d->saveSettingsBox->conflictRule());
 
@@ -430,7 +435,7 @@ void BatchDialog::slotStartStop()
 
         if (d->fileList.empty())
         {
-            KMessageBox::error(this, i18n("There is no Raw file to process in the list!"));
+            KMessageBox::error(this, i18n("There is no RAW file in the list to process."));
             busy(false);
             slotAborted();
             return;
@@ -461,6 +466,9 @@ void BatchDialog::slotStartStop()
         rawDecodingSettings.caMultiplier[1]            = d->decodingSettingsBox->caBlueMultiplier();
         rawDecodingSettings.RAWQuality                 = d->decodingSettingsBox->quality();
         rawDecodingSettings.outputColorSpace           = d->decodingSettingsBox->outputColorSpace();
+#if KDCRAW_VERSION >= 0x000500
+        rawDecodingSettings.autoBrightness             = d->decodingSettingsBox->useAutoBrightness();
+#endif
 
         d->thread->setRawDecodingSettings(rawDecodingSettings, d->saveSettingsBox->fileFormat());
         processOne();
@@ -644,13 +652,13 @@ void BatchDialog::busy(bool busy)
     {
         setButtonIcon(Apply, KIcon("process-stop"));
         setButtonText(Apply, i18n("&Abort"));
-        setButtonToolTip(Apply, i18n("Abort the current Raw files conversion"));
+        setButtonToolTip(Apply, i18n("Abort the current RAW file conversion"));
     }
     else
     {
         setButtonIcon(Apply, KIcon("system-run"));
         setButtonText(Apply, i18n("Con&vert"));
-        setButtonToolTip(Apply, i18n("Start converting the Raw images from current settings"));
+        setButtonToolTip(Apply, i18n("Start converting the RAW images using current settings."));
     }
 
     d->decodingSettingsBox->setEnabled(!d->busy);
@@ -700,7 +708,7 @@ void BatchDialog::processed(const KUrl& url, const QString& tmpFile)
         struct stat statBuf;
         if (::stat(QFile::encodeName(destFile), &statBuf) == 0)
         {
-            KIO::RenameDialog dlg(this, i18n("Save Raw Image converted from '%1' as",
+            KIO::RenameDialog dlg(this, i18n("Save RAW image converted from '%1' as",
                                   d->currentConvertItem->url().fileName()),
                                   tmpFile, destFile,
                                   KIO::RenameDialog_Mode(KIO::M_SINGLE | KIO::M_OVERWRITE | KIO::M_SKIP));
