@@ -24,14 +24,14 @@
 #include "timeadjustdialog.h"
 #include "timeadjustdialog.moc"
 
-// C ANSI includes.
+// C ANSI includes
 
 extern "C"
 {
 #include <utime.h>
 }
 
-// Qt includes.
+// Qt includes
 
 #include <QButtonGroup>
 #include <QCheckBox>
@@ -46,7 +46,7 @@ extern "C"
 #include <QToolButton>
 #include <QVBoxLayout>
 
-// KDE includes.
+// KDE includes
 
 #include <kaboutdata.h>
 #include <kapplication.h>
@@ -63,17 +63,17 @@ extern "C"
 #include <ktoolinvocation.h>
 #include <kvbox.h>
 
-// LibKIPI includes.
+// LibKIPI includes
 
 #include <libkipi/interface.h>
 #include <libkipi/imageinfo.h>
 
-// LibKExiv2 includes.
+// LibKExiv2 includes
 
 #include <libkexiv2/version.h>
 #include <libkexiv2/kexiv2.h>
 
-// Local includes.
+// Local includes
 
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
@@ -169,7 +169,7 @@ TimeAdjustDialog::TimeAdjustDialog(KIPI::Interface* interface, QWidget* parent)
     d->about = new KIPIPlugins::KPAboutData(ki18n("Time Adjust"),
                    0,
                    KAboutData::License_GPL,
-                   ki18n("A Kipi plugin for adjusting time stamp of picture files"),
+                   ki18n("A Kipi plugin for adjusting the timestamp of picture files"),
                    ki18n("(c) 2003-2005, Jesper K. Pedersen\n"
                          "(c) 2006-2009, Gilles Caulier"));
 
